@@ -1,5 +1,9 @@
 import logging
+import os
+
 import numpy as np
+import pandas
+
 from sherlockpipe.star import starinfo
 from sherlockpipe.objectinfo.ObjectProcessingError import ObjectProcessingError
 from sherlockpipe.objectinfo.preparer.LightcurveBuilder import LightcurveBuilder
@@ -7,7 +11,6 @@ import lightkurve as lk
 import matplotlib.pyplot as plt
 import csv
 
-
 class MissionLightcurveBuilder(LightcurveBuilder):
     def __init__(self):
         super().__init__()
@@ -23,17 +26,15 @@ class MissionLightcurveBuilder(LightcurveBuilder):
             raise ValueError("Wrong object id " + mission_id)
         star_info = starinfo.StarInfo(sherlock_id, *self.star_catalogs[mission_prefix].catalog_info(id))
         logging.info("Downloading lightcurve files...")
+        sectors = None if object_info.sectors == 'all' or mission != "TESS" else object_info.sectors
+        quarters = None if object_info.sectors == 'all' or mission != "K2" else object_info.sectors
+        campaigns = None if object_info.sectors == 'all' or mission != "Kepler" else object_info.sectors
         if object_info.aperture_file is None:
-            if mission == "TESS" and object_info.sectors != 'all':
-                lcf = lk.search_lightcurvefile(str(mission_id), mission=mission, cadence="short", sector=object_info.sectors)\
-                    .download_all()
-            elif mission == "TESS":
-                lcf = lk.search_lightcurvefile(str(mission_id), mission=mission, cadence="short").download_all()
-            elif object_info.sectors != 'all':
-                lcf = lk.search_lightcurvefile(str(mission_id), mission=mission, cadence="short", quarter=object_info.sectors)\
-                    .download_all()
-            else:
-                lcf = lk.search_lightcurvefile(str(mission_id), mission=mission, cadence="short").download_all()
+            lcf_search_results = lk.search_lightcurve(str(mission_id), mission=mission, cadence="short",
+                                           sector=sectors, quarter=quarters,
+                                           campaign=campaigns, author=self.authors[mission])
+            lcf = lcf_search_results.download_all()
+            lc_data = self.extract_lc_data(lcf)
             if lcf is None:
                 raise ObjectProcessingError("Light curve not found for object id " + mission_id)
             lc = None
@@ -60,19 +61,13 @@ class MissionLightcurveBuilder(LightcurveBuilder):
                 logging.info("Correcting K2 motion in light curve...")
                 quarters = [lcfile.campaign for lcfile in lcf]
                 lc = lc.to_corrector("sff").correct(windows=20)
-            return lc, star_info, transits_min_count, np.unique(sectors), np.unique(quarters)
+            return lc, lc_data, star_info, transits_min_count, np.unique(sectors), np.unique(quarters)
         else:
             logging.info("Using user apertures!")
-            if mission == "TESS" and object_info.sectors != 'all':
-                tpfs = lk.search_targetpixelfile(str(mission_id), mission=mission, cadence="short",
-                                                 sector=object_info.sectors).download_all()
-            elif mission == "TESS":
-                tpfs = lk.search_targetpixelfile(str(mission_id), mission=mission, cadence="short").download_all()
-            elif object_info.sectors != 'all':
-                tpfs = lk.search_targetpixelfile(str(mission_id), mission=mission, cadence="short",
-                                                 quarter=object_info.sectors).download_all()
-            else:
-                tpfs = lk.search_targetpixelfile(str(mission_id), mission=mission, cadence="short").download_all()
+            tpf_search_results = lk.search_targetpixelfile(str(mission_id), mission=mission, cadence="short",
+                                             sector=sectors, quarter=quarters, campaign=campaigns,
+                                             author=self.authors[mission])
+            tpfs = tpf_search_results.download_all()
             apertures = {}
             if isinstance(object_info.aperture_file, str):
                 aperture = []
@@ -168,7 +163,8 @@ class MissionLightcurveBuilder(LightcurveBuilder):
             if mission_prefix == self.MISSION_ID_KEPLER_2:
                 logging.info("Correcting K2 motion in light curve...")
                 quarters = [lcfile.campaign for lcfile in tpfs]
-            return lc, star_info, transits_min_count, np.unique(sectors), np.unique(quarters)
+            lc_data = None
+            return lc, lc_data, star_info, transits_min_count, np.unique(sectors), np.unique(quarters)
 
     def __calculate_transits_min_count(self, len_data):
         return 1 if len_data == 1 else 2
