@@ -16,5 +16,7 @@ from transitleastsquares.grid import period_grid
 from transitleastsquares.stats import FAP
 from transitleastsquares.catalog import catalog_info
 from transitleastsquares.core import fold
-from .template_generator.transit_template_generator import TransitTemplateGenerator
+from transitleastsquares.template_generator.transit_template_generator import TransitTemplateGenerator
+from transitleastsquares.template_generator.default_transit_template_generator import DefaultTransitTemplateGenerator
+from transitleastsquares.results import transitleastsquaresresults
 from transitleastsquares import version
