@@ -1,8 +1,10 @@
 import os
 import shutil
+import sys
 import time
 from argparse import ArgumentParser
-
+import sherlockpipe.eleanor
+sys.modules['eleanor'] = sys.modules['sherlockpipe.eleanor']
 import eleanor
 from sherlockpipe.vet import Vetter
 from sherlockpipe.ois.OisManager import OisManager
@@ -63,11 +65,14 @@ class Updater:
                 os.mkdir(eleanormetadata)
             for sector in range(1, 52):
                 sectorpath = eleanorpath + '/metadata/s{:04d}'.format(sector)
+                if os.path.exists(sectorpath) and os.path.isdir(sectorpath) and not os.listdir(sectorpath):
+                    os.rmdir(sectorpath)
                 if not os.path.exists(sectorpath) or not os.path.isdir(sectorpath) or not os.listdir(sectorpath):
                     try:
                         eleanor.Update(sector)
                     except:
                         os.rmdir(sectorpath)
+                        break
             with open(os.path.join(os.path.expanduser('~'), '.sherlockpipe/timestamp_eleanor.txt'), 'w+') as f:
                 f.write(str(time.time()))
         if (force or time.time() - float(latte_timestamp) > 3600 * 24 * 7) and not ois:
